@@ -6,7 +6,7 @@ import ujson
 import numpy as np
 from scaleapi import ScaleClient
 
-s3 = boto3.client("s3")
+_S3 = None
 
 # Format/ Parsing helpers
 
@@ -60,6 +60,11 @@ def get_default_template():
 
 # S3 helpers
 
+def get_s3_client():
+    global _S3
+    if _S3 is None:
+        _S3 = boto3.client("s3")
+    return _S3
 
 def fp_md5(fp: BytesIO):
     fp.seek(0)
@@ -73,6 +78,7 @@ def fp_md5(fp: BytesIO):
 
 
 def get_s3_etag(bucket, key):
+    s3 = get_s3_client()
     try:
         return s3.head_object(Bucket=bucket, Key=key)["ETag"].strip('"')
     except Exception:
@@ -80,6 +86,7 @@ def get_s3_etag(bucket, key):
 
 
 def get_signed_url(bucket: str, path: str) -> str:
+    s3 = get_s3_client()
     signed_url = s3.generate_presigned_url(
         "get_object", Params={"Bucket": bucket, "Key": f"{path}/scene.json"}
     )
@@ -87,6 +94,8 @@ def get_signed_url(bucket: str, path: str) -> str:
 
 
 def s3_smart_upload(bucket, key, fileobj, content_type):
+    s3 = get_s3_client()
+
     s3_hash = get_s3_etag(bucket, key)
     local_hash = fp_md5(fileobj)
 
