@@ -2,6 +2,7 @@ import zipfile
 from concurrent import futures
 from io import BytesIO
 from typing import MutableMapping, List, Dict
+from tqdm import tqdm
 
 import numpy as np
 import pandas as pd
@@ -248,11 +249,13 @@ class LidarScene:
     def scale_file_upload(
         self,
         project_name: str,
+        verbose: float = True
     ):
         """Save scene in Scale file
 
         :param project_name: File project name
         :type project_name: str
+        :type verbose: Set to false to not show the progress bar
 
         :return: Scene file url
         :rtype: str
@@ -260,19 +263,25 @@ class LidarScene:
         """
 
         print("Uploading scene to Scale file")
-
         frames_attachments_urls = []
-
         with futures.ThreadPoolExecutor(max_workers=UPLOAD_POOL_SIZE) as executor:
-            future_list = [
-                executor.submit(LidarFrame.scale_file_upload, frame, project_name)
-                for frame in self.frames
-            ]
+            if verbose is False:
+                future_list = [
+                    executor.submit(LidarFrame.scale_file_upload, frame, project_name)
+                    for frame in self.frames
+                ]
+            else:
+                future_list = [
+                    executor.submit(LidarFrame.scale_file_upload, frame, project_name)
+                    for frame in tqdm(self.frames)
+                ]
 
         for attachment in futures.as_completed(future_list):
             frames_attachments_urls.append(attachment.result())
 
         self.scale_file_attachments = frames_attachments_urls
+
+        print(f"Finishes uploading scene to Scale file, uploaded {len(frames_attachments_urls)} frames")
         return self.scale_file_attachments
 
     def save_task(self, filepath: str, template=None):
